pub trait AsString {
// Required method
fn as_string(self) -> String;
}Expand description
We require to use a custom trait because we need to customize some of the string transformation and we need to control the String conversion ourself.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".