Module numeric

Module numeric 

Traits

NumericAddable
Trait for types that can be added to a BigDecimal in-place
NumericComparable
Trait for types that can be compared against a BigDecimal for min/max operations
ToBigDecimal
Trait for types that can be converted to BigDecimal