Module database

Module database 

👎Deprecated since 4.0.0: The module database exists for backward compatibility reason, it should NOT be used anymore. Replace substreams_database_change::pb::database::<…> by substreams_database_change::pb::sf::substreams::sink::database::v1::<…>, this module will be removed in future versions.
The module database exists for backward compatibility reason, it should NOT be used anymore.

Replace substreams_database_change::pb::database::<...> by substreams_database_change::pb::sf::substreams::sink::database::v1::<...>, this module will be removed in future versions.

A simple search/replace is usually sufficient to update your code.

Modules

fieldDeprecated
table_changeDeprecated

Type Aliases

CompositePrimaryKeyDeprecated
DatabaseChangesDeprecated
FieldDeprecated
TableChangeDeprecated