pub type CompositePrimaryKey = CompositePrimaryKey;👎Deprecated since 4.0.0: Use substreams_database_change::pb::sf::substreams::sink::database::v1 instead, this module will be removed in future versions.
Aliased Type
pub struct CompositePrimaryKey {
pub keys: HashMap<String, String>,
}Fields
keys: HashMap<String, String>keys is a map from column name to column value for each part of the composite primary key. All values are represented as strings and will be converted to the appropriate type by the sink. Example: {“user_id”: “123”, “post_id”: “456”} for a table with composite primary key (user_id, post_id)