DatabaseChanges

Type Alias DatabaseChanges 

pub type DatabaseChanges = DatabaseChanges;
👎Deprecated since 4.0.0: Use substreams_database_change::pb::sf::substreams::sink::database::v1 instead, this module will be removed in future versions.

Aliased Type

pub struct DatabaseChanges {
    pub table_changes: Vec<TableChange>,
}

Fields

table_changes: Vec<TableChange>

table_changes is an ordered list of changes to apply to database tables. The changes are applied in the order they appear in this list.