Module numeric
substreams_
database_
change
4.0.0
Module numeric
Module Items
Traits
In crate substreams_
database_
change
substreams_database_change
Module
numeric
Traits

Numeric
Addable
Trait for types that can be added to a BigDecimal in-place
Numeric
Comparable
Trait for types that can be compared against a BigDecimal for min/max operations
ToBig
Decimal
Trait for types that can be converted to BigDecimal